ParsedVotingProcedure class sealed
- Annotations
-
- @freezed
Constructors
- ParsedVotingProcedure({required VoteOption vote, required ParsedAnchor? anchor})
-
factory
Properties
- anchor → ParsedAnchor?
-
no setterinherited
-
copyWith
→ $ParsedVotingProcedureCopyWith<
ParsedVotingProcedure> -
Create a copy of ParsedVotingProcedure
with the given fields replaced by the non-null parameter values.
no setterinherited
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- vote → VoteOption
-
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited